import request from './request'
import { API_ENDPOINTS } from '../config/api.config'

export const TaskAPI = {
  /**
   * 获取任务列表
   * @param {Object} params 查询参数
   * @param {number} params.page 页码
   * @param {number} params.pageSize 每页数量
   * @param {number} params.status 任务状态
   */
  getTaskList(params) {
    return request.get(API_ENDPOINTS.TASK.LIST, { params })
  },

  /**
   * 获取任务进程信息
   * @param {string} taskId 任务ID
   */
  getProcessInfo(taskId) {
    return request.get(`/Management/GetProcessInfo/${taskId}`)
  },

  /**
   * 删除任务
   * @param {string} taskId 任务ID
   */
  deleteTask(taskId) {
    return request.delete(`/Management/DeleteTask/${taskId}`)
  },

  /**
   * 获取任务详细信息
   * @param {string} taskId 任务ID
   */
  getTaskDetails(taskId) {
    return request.get(`/Management/GetTaskDetail/${taskId}`)
  },

  /**
   * 终止任务
   * @param {string} taskId 任务ID
   */
  killTask(taskId) {
    return request.post(`/Management/KillTask/${taskId}`)
  },

  /**
   * 获取系统配置
   */
  getSystemConfig() {
    return request.get('/Management/GetSystemConfig')
  },

  /**
   * 获取任务概览数据
   */
  getTaskOverview() {
    return request.get('/Management/GetTaskOverview')
  },

  /**
   * 重试任务
   * @param {string} taskId 任务ID
   */
  retryTask(taskId) {
    return request.post(`/Management/RetryTask/${taskId}`)
  },

  /**
   * 立即执行任务（调整优先级）
   * @param {string} taskId 任务ID
   */
  prioritizeTask(taskId) {
    return request.post(`/Management/PrioritizeTask/${taskId}`)
  },

  /**
   * 立即执行任务
   * @param {string} taskId 任务ID
   */
  executeImmediately(taskId) {
    return request.post(`/Management/ExecuteImmediately/${taskId}`)
  },

  /**
   * 添加离线任务
   * @param {string} url 下载地址
   */
  addOfflineTask(url) {
    return request.post('/AddOfflineTask', null, {
      params: { url }
    })
  },

  /**
   * 获取系统日志
   * @param {Object} params 查询参数
   * @param {number} params.page 页码
   * @param {number} params.pageSize 每页数量
   * @param {string} [params.level] 日志级别
   * @param {string} [params.keyword] 搜索关键词
   * @param {string} [params.startTime] 开始时间
   * @param {string} [params.endTime] 结束时间
   */
  getSystemLogs(params) {
    return request.get('/Management/GetSystemLogs', { params })
  },

  /**
   * 获取数据库连接池信息
   */
  getConnectionPoolInfo() {
    return request.get('/Management/GetConnectionPoolInfo')
  },

  /**
   * 获取任务下载历史
   * @param {string} taskId 任务ID
   */
  getDownloadHistory(taskId) {
    return request.get(`/Management/GetDownloadHistory/${taskId}`)
  },

  /**
   * 搜索任务
   * @param {Object} params 搜索参数
   * @param {string} params.keyword 搜索关键词
   * @param {number} params.page 页码
   * @param {number} params.pageSize 每页数量
   */
  searchTasks(params) {
    return request.get('/Management/SearchTasks', { params })
  }
} 