import request from './request'

export const UserAPI = {
  /**
   * 用户注册
   * @param {Object} data 注册信息
   * @param {string} data.username 用户名
   * @param {string} data.password 密码
   */
  register(data) {
    return request.post('/user/register', data)
  },

  /**
   * 用户登录
   * @param {Object} data
   * @param {string} data.username - 用户名或邮箱
   * @param {string} data.password - 密码
   */
  login(data) {
    return request.post('/user/login', data)
  },

  /**
   * 获取用户信息
   */
  getUserInfo() {
    return request.get('/user/info')
  },

  /**
   * 获取用户列表
   * @param {Object} params 查询参数
   * @param {number} params.page 页码
   * @param {number} params.pageSize 每页数量
   */
  getUserList(params) {
    return request.get('/user/list', { params })
  },

  /**
   * 修改用户权限
   * @param {string} userId 用户ID
   * @param {number} newMask 新的权限掩码
   */
  updateUserMask(userId, newMask) {
    return request.post(`/user/updateMask/${userId}`, {
      newMask
    })
  },

  /**
   * 修改昵称
   * @param {string} newNickname 新昵称
   */
  updateNickname(newNickname) {
    return request.post('/user/updateNickname', {
      newNickname
    })
  },

  /**
   * 修改密码
   * @param {string} oldPassword 旧密码
   * @param {string} newPassword 新密码
   */
  updatePassword(oldPassword, newPassword) {
    return request.post('/user/updatePassword', {
      oldPassword,
      newPassword
    })
  },

  /**
   * 重置用户密码（超级管理员）
   * @param {string} userId 用户ID
   * @param {string} newPassword 新密码
   */
  resetPassword(userId, newPassword) {
    return request.post(`/user/resetPassword/${userId}`, {
      newPassword
    })
  },

  /**
   * 获取用户事件列表
   * @param {Object} params 查询参数
   * @param {number} params.page 页码
   * @param {number} params.pageSize 每页数量
   * @param {string} [params.userId] 用户ID（超级管理员可选）
   * @param {string} [params.keyword] 搜索关键词
   */
  getUserEvents(params) {
    return request.get('/user/events', { params })
  },

  /**
   * 修改用户昵称（超级管理员）
   * @param {string} userId 用户ID
   * @param {string} newNickname 新昵称
   */
  updateUserNickname(userId, newNickname) {
    return request.post(`/user/updateNickname/${userId}`, {
      newNickname
    })
  },

  /**
   * 添加用户
   * @param {Object} data 用户信息
   * @param {string} data.username 用户名
   * @param {string} data.password 密码
   * @param {string} data.nickname 昵称
   * @param {string} data.email 邮箱
   * @param {number} data.mask 权限掩码
   */
  addUser(data) {
    return request.post('/Management/AddUser', data)
  }
} 