import { createApp } from 'vue'
import App from './App.vue'
import router from './router'
import ElementPlus from 'element-plus'
import zhCn from 'element-plus/dist/locale/zh-cn.mjs'
import 'element-plus/dist/index.css'
import * as ElementPlusIconsVue from '@element-plus/icons-vue'
import { initFingerprint } from '@/utils/fingerprint'
import { setGlobalFingerprint } from '@/api/request'

const app = createApp(App)

// 注册所有图标
for (const [key, component] of Object.entries(ElementPlusIconsVue)) {
  app.component(key, component)
}

// 配置 Element Plus 使用中文
app.use(ElementPlus, {
  locale: zhCn,
})

app.use(router)

// 初始化指纹后再挂载应用
initFingerprint().then(fingerprint => {
  if (fingerprint) {
    setGlobalFingerprint(fingerprint)
  }
  app.mount('#app')
}).catch(() => {
  // 即使获取指纹失败也继续挂载应用
  app.mount('#app')
}) 