// 用户权限掩码
export const UserMask = {
  Guest: -1,
  User: 0,
  Admin: 1,
  SuperAdmin: 2
}

// 检查用户是否有权限
export function hasPermission(requiredMask, userMask) {
  // 超级管理员拥有所有权限
  if (userMask === UserMask.SuperAdmin) {
    return true
  }

  // 管理员拥有除超级管理员外的所有权限
  if (userMask === UserMask.Admin && requiredMask !== UserMask.SuperAdmin) {
    return true
  }

  // 普通用户只能访问用户级别的功能
  if (userMask === UserMask.User && requiredMask <= UserMask.User) {
    return true
  }

  // 访客只能访问访客功能
  if (userMask === UserMask.Guest && requiredMask === UserMask.Guest) {
    return true
  }

  return false
}

// 获取用户角色标签
export function getUserRoleLabel(mask) {
  switch (mask) {
    case UserMask.SuperAdmin:
      return '超级管理员'
    case UserMask.Admin:
      return '管理员'
    case UserMask.User:
      return '普通用户'
    case UserMask.Guest:
      return '访客'
    default:
      return '未知'
  }
} 